/******************************************************************/
/*                                                                */
/* Copyright (C) 1994 - 2006, IBM, Ltd.                           */
/* All Rights Reserved                                            */
/*                                                                */
/*----------------------------------------------------------------*/
/*                                                                */
/* THIS IS UNPUBLISHED PROPRIETARY SOURCE CODE                    */
/* The copyright notice above does not evidence any               */
/* actual or intended publication of such source code.            */
/*                                                                */
/* RESTRICTED RIGHTS:                                             */
/*                                                                */
/* This file may have been supplied under a license.              */
/* It may be used, disclosed, and/or copied only as permitted     */
/* under such license agreement. Any copy must contain the        */
/* above copyright notice and this restricted rights notice.      */
/* Use, copying, and/or disclosure of the file is strictly        */
/* prohibited unless otherwise provided in the license agreement. */
/*                                                                */
/******************************************************************/


/**
********************************************************************************
*
* CreateSchema(server, dbname, schema, host, username, password, port, action)
*
* Function to create the requested database schema
*
********************************************************************************
*/
function CreateSchema(server, dbname, schema, host, username, password, port, action)
{
    var success = false;

    //
    // Set up platform specific variables
    //
    var separator = "/";
    var topLine = "#!/bin/sh";
    var oraEnv = "ORACLE_HOME=" + GetNcHome() + "/platform/" + ncipackage.shortArch + "/oci9.2\n"
               + "export ORACLE_HOME\n"
               + "LD_LIBRARY_PATH=$ORACLE_HOME/lib\n"
               + "export LD_LIBRARY_PATH\n";
    var mysqlEnv = "MYSQL_HOME=\"" + GetNcHome() + "/platform/" + ncipackage.shortArch + "/mysql5.0\"\n"
                 + "export MYSQL_HOME";

    var sqllib = PropertyValue("NCIM.SQLLIB");
    var db2Env = "";
    if (sqllib)
    {   
        db2Env = ". " + sqllib + "/db2profile\n";
    }

    var perlOS = "";

    if (ncipackage.shortArch == "solaris2")
    {
        perlOS = "sun4-solaris-thread-multi";
    }
    else if (ncipackage.shortArch == "aix5")
    {
        perlOS = "aix-thread-multi";
    }
    else if (ncipackage.shortArch == "linux2x86")
    {
        perlOS = "i686-linux-thread-multi";
    }

    var perlSript = GetNcHome() + "/precision/scripts/sql/create_db_schemas.pl";
    var perlCmd = GetNcHome() + "/precision/perl/bin/perl";
    var perlEnv = "";
    var perlLib = "PERL5LIB=\""
                   + GetNcHome() + "/precision/perl/lib/5.8.8/" + perlOS + ":"
                   + GetNcHome() + "/precision/perl/lib/5.8.8:"
                   + GetNcHome() + "/precision/perl/lib/site_perl/5.8.8/" + perlOS + ":"
                   + GetNcHome() + "/precision/perl/lib/site_perl/5.8.8:"
                   + GetNcHome() + "/precision/perl/lib/site_perl\"\n"
                   + "export PERL5LIB";

    if (ncipackage.shortArch == "win32")
    {
        separator = "\\";
        topLine = "@echo off";
        db2Env = "path " + sqllib + "\\bin;%Path%";
        oraEnv = "set ORACLE_HOME=" + GetNcHome() + "\\platform\\win32\\oci9.2\n"
               + "path %ORACLE_HOME%\\bin;%Path%";
        mysqlEnv = "path " + GetNcHome() + "\\platform\\win32\\mysql5.0\\bin;%Path%";
        perlEnv = "path " + GetNcHome() + "\\platform\\win32\\bin;"
                + GetNcHome() +"\\precision\\perl\\bin;%Path%";

        perlSript = GetNcHome() + "\\precision\\scripts\\sql\\create_db_schemas.pl";
        perlCmd = GetNcHome() + "\\precision\\perl\\bin\\perl.exe";
        perlLib = "set PERL5LIB="
                   + GetNcHome() + "\\precision\\perl\\lib;"
                   + GetNcHome() + "\\precision\\perl\\site\\lib\n";
    }

    //
    // Build the name of the logfile to use
    //
    var logfileName = GetNcHome() + separator + "log" + separator
                    + "install" + separator + "ncp_create_" + action + "_db.log";
    //
    // Now attempt to execute a script which will create the NCIM database schema
    //
    try
    {
        //
        // Now create a script to run the relocation of Perl
        //
        var scriptFileName = GetNcHome() + separator + "ncp_create_" + action + "_db.bat";

        var scriptFile = Components.classes["@mozilla.org/file/local;1"].
            createInstance(Components.interfaces.nsILocalFile);
        scriptFile.initWithPath(scriptFileName);

        var scriptContents = topLine + "\n"
                           + oraEnv + "\n"
                           + mysqlEnv + "\n"
                           + db2Env + "\n"
                           + perlEnv + "\n"
                           + perlLib + "\n"
                           + "\"" + perlCmd + "\" \"" + perlSript + "\""
                             + " -server \"" + server + "\""
                             + " -dbname \"" + dbname + "\""
                             + " -schema \"" + schema + "\""
                             + " -host \"" + host + "\""
                             + " -username \"" + username + "\""
                             + " -password \"" + password + "\""
                             + " -port \"" + port + "\""
                             + " -action \"" + action + "\""
                           + " > \"" + logfileName + "\" 2>&1\n";

        var foStream2 = Components.classes["@mozilla.org/network/file-output-stream;1"].
            createInstance(Components.interfaces.nsIFileOutputStream);
        foStream2.init(scriptFile, 0x02 | 0x08 | 0x20, 0777, 0); // write, create, truncate
        foStream2.write(scriptContents, scriptContents.length);
        foStream2.close();

        //
        // Now run the script.
        //
        var process = Components.classes["@mozilla.org/process/util;1"].
            createInstance(Components.interfaces.nsIProcess);
        process.init(scriptFile);

        var args = [];
        process.run(true, args, args.length);

        //
        // Now open the file and check for critical errors
        //
        success = CheckLogForErrors(logfileName);

        //
        // Finally, clean up the temporary file.
        //
        scriptFile.remove(false);
    }
    catch(e)
    {
        Log(0, e);
    }

    return success;
}

/**
********************************************************************************
*
* CheckLogForErrors(logfileName)
*
* This function will open the file passed to it and check for any critical
* errors by searching for the string:
*
*   Level: critical
*
********************************************************************************
*/
function CheckLogForErrors(logfileName)
{
    var success = false;

    try
    {
        var file = Components.classes["@mozilla.org/file/local;1"].
            createInstance(Components.interfaces.nsILocalFile);
        file.initWithPath(logfileName);

        var logfileStream = Components.classes["@mozilla.org/network/file-input-stream;1"].
            createInstance(Components.interfaces.nsIFileInputStream);

        logfileStream.init(file, 1, 0, 0); 

        var lineReader = logfileStream.QueryInterface(Components.interfaces.nsILineInputStream);
        var lineObj = {};

        //
        // If we go this far then we must at least have opened the log file
        //
        success = true;

        while (lineReader.readLine(lineObj) && success == true)
        {
            var line = lineObj.value;

            var regex = new RegExp("Level: critical");

            if (regex.test(line))
            {
                Log(0, line);
                success = false;
            }
        } 

        logfileStream.close();
    }
    catch(e)
    {
        Log(0, e);
    }

    if (success == false)
    {
        var packageMgr = Components.classes["@micromuse.com/NCIPackageManager;1"].getService(Components.interfaces.nsINCIPackageManager);

        var schemaWarnPage = packageMgr.pages.getById("ncim_schema_warning");
        if (schemaWarnPage)
        {
            schemaWarnPage.visible = true;
        }
    }

    return success;
}
