/******************************************************************/
/*                                                                */
/* Copyright (C) 1994 - 2007, IBM, Ltd.                           */
/* All Rights Reserved                                            */
/*                                                                */
/*----------------------------------------------------------------*/
/*                                                                */
/* THIS IS UNPUBLISHED PROPRIETARY SOURCE CODE                    */
/* The copyright notice above does not evidence any               */
/* actual or intended publication of such source code.            */
/*                                                                */
/* RESTRICTED RIGHTS:                                             */
/*                                                                */
/* This file may have been supplied under a license.              */
/* It may be used, disclosed, and/or copied only as permitted     */
/* under such license agreement. Any copy must contain the        */
/* above copyright notice and this restricted rights notice.      */
/* Use, copying, and/or disclosure of the file is strictly        */
/* prohibited unless otherwise provided in the license agreement. */
/*                                                                */
/******************************************************************/


/**
********************************************************************************
*
* CreateNcimPrecisionDb()
*
* Function to create the Ncmonitor and Ncmib database schema and the extra
* tables needed in the Ncim schema for PrecisionIP's WebApps.
*
********************************************************************************
*/
function CreateNcimPrecisionDb()
{
    //
    // Create the ncmib schema in the local mysql database and
    // grant the Precision MySQL user access to the schema.
    //
    var ncmibSchema = "ncmib";
    CreateSchema(   "mysql",
                    ncmibSchema,  // For MySQL the Db name and Schema name are the same
                    ncmibSchema,
                    'localhost',
                    PropertyValue("MYSQL50.ADMINUSERNAME"),
                    PropertyValue("MYSQL50.ADMINPASSWORD"),
                    PropertyValue("MYSQL50.PORT"),
                    "ncmib");

    MySQLGrantUserRights(   PropertyValue("PRECISION.MYSQLUSERNAME"),
                            PropertyValue("PRECISION.MYSQLPASSWORD"),
                            ncmibSchema);

    if (PropertyValue("NCIM.SERVER") == "mysql")
    {
        MySQLGrantUserRights(   PropertyValue("NCIM.USERNAME"),
                                PropertyValue("NCIM.PASSWORD"),
                                ncmibSchema);
    }

    //
    // We may or may not be creating the NCIM schema
    //
    var create = PropertyValue("NCIM.CREATE");
    if (create == "no")
    {
        return;
    }

    //
    // Create the Precision IP part of the NCIM schema,
    // e.g. the chassis table and so forth.
    //
    CreateSchema(   PropertyValue("NCIM.SERVER"),
                    PropertyValue("NCIM.DBNAME"),
                    PropertyValue("NCIM.NCIMSCHEMA"),
                    PropertyValue("NCIM.HOST"),
                    PropertyValue("NCIM.USERNAME"),
                    PropertyValue("NCIM.PASSWORD"),
                    PropertyValue("NCIM.PORT"),
                    "ncim_pip");

    //
    // Create the ncmonitor schema for the GUIs
    //
    if (PropertyValue("NCIM.SERVER") == "mysql")
    {
        MySQLGrantUserRights(   PropertyValue("NCIM.USERNAME"),
                                PropertyValue("NCIM.PASSWORD"),
                                PropertyValue("NCIM.MONITORSCHEMA"));
    }

    CreateSchema(   PropertyValue("NCIM.SERVER"),
                    PropertyValue("NCIM.DBNAME"),
                    PropertyValue("NCIM.MONITORSCHEMA"),
                    PropertyValue("NCIM.HOST"),
                    PropertyValue("NCIM.USERNAME"),
                    PropertyValue("NCIM.PASSWORD"),
                    PropertyValue("NCIM.PORT"),
                    "ncmonitor");

    //
    // The monitoring also needs a copy of ncmib. But we only need
    // to create it if the the NCIM schema is not the local MySQL
    //
    if (PropertyValue("NCIM.SERVER") != "mysql" ||
        PropertyValue("NCIM.HOST") != PropertyValue("MYSQL50.HOST") ||
        PropertyValue("NCIM.PORT") != PropertyValue("MYSQL50.PORT"))
    {
        CreateSchema(   PropertyValue("NCIM.SERVER"),
                        PropertyValue("NCIM.DBNAME"),
                        PropertyValue("NCIM.MIBSCHEMA"),
                        PropertyValue("NCIM.HOST"),
                        PropertyValue("NCIM.USERNAME"),
                        PropertyValue("NCIM.PASSWORD"),
                        PropertyValue("NCIM.PORT"),
                        "ncmib");
    }
}

/********************************* End of File ********************************/
